.. schedula documentation master file, created by
   sphinx-quickstart on Sat May 23 16:20:31 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst
    :start-after: .. _start-intro:
    :end-before: .. _end-intro:

.. include:: ../README.rst
    :start-after: .. _start-badges:
    :end-before: .. _end-badges:

.. toctree::
    :maxdepth: 1
    :numbered:
    :caption: Table of Contents
    :name: mastertoc

    about
    install
    tutorial
    async
    contrib
    donate
    api
    change

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`